@@ -1,18 +1,20 @@
 //! Particle Swarm Optimization.
 //!
 //! <https://en.wikipedia.org/wiki/Particle_swarm_optimization>
-use crate::{thread_pool::ThreadPool, utility::*, *};
+use crate::utility::prelude::*;
 
 /// Particle Swarm Optimization settings.
 pub struct Pso {
-    /// Base setting.
-    pub base: BasicSetting,
-    /// Cognition factor.
-    pub cognition: f64,
-    /// Social factor.
-    pub social: f64,
-    /// Moving velocity.
-    pub velocity: f64,
+    base: BasicSetting,
+    cognition: f64,
+    social: f64,
+    velocity: f64,
+}
+
+impl Pso {
+    impl_builder!(cognition, f64, "Cognition factor.");
+    impl_builder!(social, f64, "Social factor.");
+    impl_builder!(velocity, f64, "Moving velocity.");
 }
 
 impl Default for Pso {
@@ -29,13 +31,17 @@ impl Default for Pso {
     }
 }
 
-impl<F: ObjFunc> Setting<F> for Pso {
+impl Setting for Pso {
     type Algorithm = Method;
 
     fn base(&self) -> &BasicSetting {
         &self.base
     }
 
+    fn base_mut(&mut self) -> &mut BasicSetting {
+        &mut self.base
+    }
+
     fn create(self) -> Self::Algorithm {
         Method {
             cognition: self.cognition,
