@@ -5,23 +5,28 @@
 //! <https://en.wikipedia.org/wiki/Genetic_algorithm>
 //!
 //! This method require floating point power function.
-use crate::{thread_pool::ThreadPool, utility::*, *};
+use crate::utility::prelude::*;
+use alloc::{vec, vec::Vec};
+use core::marker::PhantomData;
 
 /// Real-coded Genetic Algorithm settings.
-pub struct Rga {
-    /// Base setting.
-    pub base: BasicSetting,
-    /// Crossing probability.
-    pub cross: f64,
-    /// Mutation probability.
-    pub mutate: f64,
-    /// Winning probability.
-    pub win: f64,
-    /// Delta factor.
-    pub delta: f64,
+pub struct Rga<R: Respond> {
+    base: BasicSetting,
+    cross: f64,
+    mutate: f64,
+    win: f64,
+    delta: f64,
+    _marker: PhantomData<R>,
 }
 
-impl Default for Rga {
+impl<R: Respond> Rga<R> {
+    impl_builder!(cross, f64, "Crossing probability.");
+    impl_builder!(mutate, f64, "Mutation probability.");
+    impl_builder!(win, f64, "Winning probability.");
+    impl_builder!(delta, f64, "Delta factor.");
+}
+
+impl<R: Respond> Default for Rga<R> {
     fn default() -> Self {
         Self {
             base: BasicSetting {
@@ -32,17 +37,22 @@ impl Default for Rga {
             mutate: 0.05,
             win: 0.95,
             delta: 5.,
+            _marker: PhantomData,
         }
     }
 }
 
-impl<F: ObjFunc> Setting<F> for Rga {
-    type Algorithm = Method<F::Respond>;
+impl<R: Respond> Setting for Rga<R> {
+    type Algorithm = Method<R>;
 
     fn base(&self) -> &BasicSetting {
         &self.base
     }
 
+    fn base_mut(&mut self) -> &mut BasicSetting {
+        &mut self.base
+    }
+
     fn create(self) -> Self::Algorithm {
         Method {
             cross: self.cross,
