@@ -1,5 +1,5 @@
-use crate::{thread_pool::ThreadPool, utility::*, *};
-use alloc::{sync::Arc, vec::Vec};
+use crate::utility::prelude::*;
+use alloc::{sync::Arc, vec, vec::Vec};
 
 /// The base class of algorithms.
 ///
@@ -18,7 +18,7 @@ pub struct Context<F: ObjFunc> {
     /// The current information of the algorithm.
     pub report: Report,
     pub(crate) reports: Vec<Report>,
-    pub(crate) rpt: u32,
+    pub(crate) rpt: u64,
     pub(crate) average: bool,
     pub(crate) adaptive: Adaptive,
     /// The objective function.
